@@ -1,6 +1,7 @@
 from pathlib import Path
 
 import numpy as np
+import pytest
 
 import fast_overlap
 
@@ -9,8 +10,10 @@ expected = np.load(str(Path(__file__).parent / "expected-overlap.npy"))
 shape = (int(np.max(ims[0]) + 1), int(np.max(ims[1]) + 1))
 
 
-def test_overlap():
-    out = fast_overlap.overlap(ims[0].astype(np.int32), ims[1].astype(np.int32), shape)
+# test a few different types but not all
+@pytest.mark.parametrize("type", [np.uint16, np.uint64, np.int32, np.int64])
+def test_overlap(type):
+    out = fast_overlap.overlap(ims[0].astype(type), ims[1].astype(type), shape)
     assert np.all(out == expected)
 
 
